## 0.1.5 - 2021-08-25

### Added

- Added flake, editorconfig, tox.ini etc files to match best practices for existing Draftable/Affinda projects (thanks @ralish!)
- 

## 0.1.4 - 2021-08-18

### Fixes:

- Update README.md to fix install instructions

## 0.1.3 - 2021-08-18

### Fixes:

- Update README.md to hard link to github hosted logo to fix display on PyPi

## 0.1.2 - 2021-08-18

- Initial release

##### Follows the format from https://keepachangelog.com/en/1.0.0/
